netapp_ontap.models.svm_storage API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.svm_storage`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SvmStorageSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SvmStorage object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `allocated: Size GET`

    Total size of the volumes in SVM, in bytes.

  `available: Size GET`

    Currently available storage capacity in SVM, in bytes.

  `limit: Size GET POST PATCH`

    Maximum storage permitted on a single SVM, in bytes.

  `limit_threshold_alert: Size GET POST PATCH`

    Indicates at what percentage of storage capacity an alert message is sent. The default value is 90.

  `limit_threshold_exceeded: bool GET`

    Indicates whether the total storage capacity exceeds the alert percentage.

  `used_percentage: Size GET`

    The percentage of storage capacity used.